#!/bin/bash
# Copyright 2016 Michal Žejdl
# MikroTik mtxrHealth - Voltage, Temperature, ProcessorFrequency

# at least five args are required
test $# -lt 5 && exit

rrdbasedir=$1
rrdfile=$2
outputdir=$3
starttime=$4
endtime=$5

# make the remote flush possible
cd $rrdbasedir || exit

test -d "$outputdir" || mkdir -p "$outputdir" || exit

# lazy (-z) is handy
options="-s $starttime -e $endtime -z"

# append rrdcached
test $# -gt 5 && options="$options --daemon $6"

filename=$(basename $rrdfile .rrd)

rrdtool graph \
$outputdir/mikrotik-$filename-Voltage-$starttime-$endtime.png \
$options -t "Voltage" -v "V" \
DEF:va=$rrdfile:Voltage:AVERAGE \
DEF:vn=$rrdfile:Voltage:MIN \
DEF:vm=$rrdfile:Voltage:MAX \
DEF:vl=$rrdfile:Voltage:LAST \
CDEF:vad=va,10,/ \
CDEF:vnd=vn,10,/ \
CDEF:vmd=vm,10,/ \
CDEF:vld=vl,10,/ \
VDEF:vaa=vad,AVERAGE \
VDEF:vnn=vnd,MINIMUM \
VDEF:vmm=vmd,MAXIMUM \
VDEF:vll=vld,LAST \
TEXTALIGN:left \
LINE2:vad#0000cc:"" \
GPRINT:vaa:"avg\: %6.2lf %s" \
GPRINT:vnn:"min\: %6.2lf %s" \
GPRINT:vmm:"max\: %6.2lf %s" \
GPRINT:vll:"lst\: %6.2lf %s\l" \

rrdtool graph \
$outputdir/mikrotik-$filename-Temperature-$starttime-$endtime.png \
$options -t "Temperature" -v "°C" \
DEF:va=$rrdfile:Temperature:AVERAGE \
DEF:vn=$rrdfile:Temperature:MIN \
DEF:vm=$rrdfile:Temperature:MAX \
DEF:vl=$rrdfile:Temperature:LAST \
CDEF:vad=va,10,/ \
CDEF:vnd=vn,10,/ \
CDEF:vmd=vm,10,/ \
CDEF:vld=vl,10,/ \
VDEF:vaa=vad,AVERAGE \
VDEF:vnn=vnd,MINIMUM \
VDEF:vmm=vmd,MAXIMUM \
VDEF:vll=vld,LAST \
TEXTALIGN:left \
LINE2:vad#0000cc:"" \
GPRINT:vaa:"avg\: %6.2lf %s" \
GPRINT:vnn:"min\: %6.2lf %s" \
GPRINT:vmm:"max\: %6.2lf %s" \
GPRINT:vll:"lst\: %6.2lf %s\l" \

rrdtool graph \
$outputdir/mikrotik-$filename-ProcessorFrequency-$starttime-$endtime.png \
$options -t "ProcessorFrequency" -v "MHz" \
DEF:va=$rrdfile:ProcessorFrequency:AVERAGE \
DEF:vn=$rrdfile:ProcessorFrequency:MIN \
DEF:vm=$rrdfile:ProcessorFrequency:MAX \
DEF:vl=$rrdfile:ProcessorFrequency:LAST \
VDEF:vaa=va,AVERAGE \
VDEF:vnn=vn,MINIMUM \
VDEF:vmm=vm,MAXIMUM \
VDEF:vll=vl,LAST \
TEXTALIGN:left \
LINE2:va#0000cc:"" \
GPRINT:vaa:"avg\: %6.2lf %s" \
GPRINT:vnn:"min\: %6.2lf %s" \
GPRINT:vmm:"max\: %6.2lf %s" \
GPRINT:vll:"lst\: %6.2lf %s\l" \
