<?php

/*
 * Copyright 2013 - 2017 Michal Žejdl
 */


// define constants here

define("date_format", "Y&#8209;m&#8209;d H:i:s");

function try_addr2name($ipa) {
	$name = gethostbyaddr($ipa);
	if ($name == $ipa) return "";
	else return "<a href=\"dns.php?id=$name\">$name</a>";
}

function address2name($ipa) {

	$name = gethostbyaddr($ipa);

	if ($name == $ipa)

		return "";
	else
		return $name;
}

function expand_ipv6($address) {
	// convert $address to 16 B and unpack it to the array
	$hexa_array = unpack("H32hexa_string", inet_pton($address));
	// add : after every fourth char and cut the last one :
	return rtrim(preg_replace(
				"/([[:xdigit:]]{4})/", "$1:", $hexa_array["hexa_string"]), ":");
}

function ipv6_compress($address) {

	$compressed = inet_ntop(inet_pton($address));

	if (empty($compressed))

		return $address;
	else
		return $compressed;
}

function debug_print($string) {
	global $debug;
	if ($debug) print("<p>$string\n");
}

function debug_time () {
	global $start_time;
	$delta = round(microtime(true) - $start_time, 3);
	debug_print("time: " . $delta . " second(s)");
}

function sysObjectID2organization ($sysObjectID)
{
	$organizations = array(
			9 => "Cisco",
			43 => "3Com",
			318 => "APC",
			776 => "Telindus",
			14988 => "MikroTik"
			);

	$numbers = explode(".", $sysObjectID);
	if (array_key_exists(7, $numbers))
		if (array_key_exists($numbers[7], $organizations))
			return $organizations[$numbers[7]];

	return false;
}

function tr_aging_class_test($number)
{
	if ($number % 2)
		$dim = "";
	else
		$dim = "-dim";

	if ($number >= 11)
		return "aging-year".$dim;

	if ($number >= 9)
		return "aging-month".$dim;

	if ($number >= 7)
		return "aging-week".$dim;

	if ($number >= 5)
		return "aging-day".$dim;

	if ($number >= 3)
		return "aging-hour".$dim;

	return "aging-now".$dim;
}

function tr_aging_class($row_number, $delta_time)
{
	if ($row_number % 2)
		$dim = "";
	else
		$dim = "-dim";

	if ($delta_time >= 31536000)
		return "aging-year".$dim;

	if ($delta_time >= 2592000)
		return "aging-month".$dim;

	if ($delta_time >= 604800)
		return "aging-week".$dim;

	if ($delta_time >= 86400)
		return "aging-day".$dim;

	if ($delta_time >= 3600)
		return "aging-hour".$dim;

	return "aging-now".$dim;
}

function date_formated($timestamp)
{
	return date(date_format, $timestamp);
}

// setting locale and domain for gettext(); obslolete
function set_i18n()
{
	// get it from conf for now; see conf.php-example for the reason
	global $locale;

	// leave now, if the $locale is not set
	if (! isset($locale))
		return;

	$domain = "nana-web";
	$directory = "./locale";

	// they said, that this is for MS Windows server
	putenv("LC_MESSAGES=$locale");

	// this is sufficient for me on CentOS Linux
	setlocale(LC_MESSAGES, $locale);

	// the search path for .mo files
	bindtextdomain($domain, $directory);

	/*
	 * gettext() returned question mark instead of national chars
	 * without this function; hardcoded UTF-8 should be changed later
	 */
	bind_textdomain_codeset($domain, "UTF-8");

	// the name of .mo file
	textdomain($domain);
}

// setting locale and domain for gettext(); support for relative paths
function set_i18n_with_document_root($locale, $document_root)
{
	// get it from conf for now; see conf.php-example for the reason
	global $locale;

	// leave now, if the $locale is not set
	if (! isset($locale))
		return;

	$domain = "nana-web";
	$directory = $document_root . "/locale";

	// they said, that this is for MS Windows server
	putenv("LC_MESSAGES=$locale");

	// this is sufficient for me on CentOS Linux
	setlocale(LC_MESSAGES, $locale);

	// the search path for .mo files
	bindtextdomain($domain, $directory);

	/*
	 * gettext() returned question mark instead of national chars
	 * without this function; hardcoded UTF-8 should be changed later
	 */
	bind_textdomain_codeset($domain, "UTF-8");

	// the name of .mo file
	textdomain($domain);
}

function page_open($document_root, $title)
{
	echo <<<EOH
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
<link href="$document_root/style.css" rel="stylesheet" type="text/css">
<title>nana - $title</title>
</head>
<body>

EOH;

	require "$document_root/head.php";
}

function page_close($document_root)
{
	require "$document_root/tail.php";

	echo <<<EOH

</body>
</html>
EOH;
}

?>
